[Qa-jenkins-scm] [jenkins.debian.net] 07/07: torbrowser tests: improve output, one screenshot less

Holger Levsen holger at moszumanska.debian.org
Thu Nov 19 10:25:58 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 4a1f53a84b03be5a0dc11087b3050ec926d1d304
Author: Holger Levsen <holger at layer-acht.org>
Date:   Thu Nov 19 03:44:45 2015 +0100

    torbrowser tests: improve output, one screenshot less
---
 TODO                            |  8 +++++++-
 bin/test_torbrowser-launcher.sh | 11 +++++------
 2 files changed, 12 insertions(+), 7 deletions(-)

diff --git a/TODO b/TODO
index fe8b7da..5e464f5 100644
--- a/TODO
+++ b/TODO
@@ -412,8 +412,14 @@ The following ideas should really only be implemented for the new 'lvc*' tests..
 
 === torbrowser-launcher_*
 
-* not sure how to test updates. maybe just run in yesterdays schroot before upgrading
+* test updates - add _and_upgrade to job names)
+** touch -d "$(date -u -d '25 hours ago' '+%Y-%m-%d %H:%M')" $FILE
+** repeat test…
+* build daily from upstream master against sid no matter if there where commits
 * test alpha releases
+** '~/.config/torbrowser/settings' file and edit the latest_version setting
+** get version from '~/.cache/torbrowser/download/RecommendedTBBVersions'
+** (warning: on update checks these files are written again…)
 * notifications should go somewhere public, after a while of testing.
 * debug why iceweasel is needed to be installed… and ca-certificates too.
 * run this in qemu and enable apparmor too?
diff --git a/bin/test_torbrowser-launcher.sh b/bin/test_torbrowser-launcher.sh
index 158c1d5..43e7b68 100755
--- a/bin/test_torbrowser-launcher.sh
+++ b/bin/test_torbrowser-launcher.sh
@@ -45,7 +45,7 @@ cleanup_all() {
 
 cleanup_duplicate_screenshots() {
 	cd $RESULTS
-	echo "$(date -u) - removing duplicate screenshots."
+	echo "$(date -u) - removing duplicate and similar creenshots."
 	# loop backwards through the screenshots and remove similar ones
 	# this results in keeping the interesting ones :)
 	MAXDIFF=2500 # pixels
@@ -60,7 +60,7 @@ cleanup_duplicate_screenshots() {
 			PIXELS=$(compare -metric AE $i $j /dev/null 2>&1 || true)
 			# if it's an integer…
 			if [[ "$PIXELS" =~ ^[0-9]+$ ]] && [ $PIXELS -le $MAXDIFF ] ; then
-				echo "$(date -u ) - removing $j, just $PIXELS pixels difference."
+				echo "$(date -u ) - removing $j, $PIXELS pixels difference."
 				rm $j
 			fi
 		done
@@ -219,8 +219,8 @@ download_and_launch() {
 		cleanup_duplicate_screenshots
 		exit 1
 	fi
-	echo "$(date -u) - waiting for torbrowser to start."
-	# allow up to 63 seconds for torbrowser to start
+	echo "$(date -u) - waiting for torbrowser to start the tor network settings dialogue."
+	# allow up to 63 seconds for torbrowser to start the tor network settings dialogue
 	for i in $(seq 1 7) ; do
 		sleep 5 ; sleep $i
 		# this directory only exists once torbrower has successfully started
@@ -229,7 +229,6 @@ download_and_launch() {
 		STATUS="$(schroot --run-session -c $SESSION -- test ! -d $BROWSER_DIR_EN/$BROWSER_PROFILE -a ! -d $BROWSER_DIR_DE/$BROWSER_PROFILE || echo $(date -u ) - torbrowser running. )"
 		if [ -n "$STATUS" ] ; then
 			sleep 10
-			update_screenshot
 			break
 		fi
 	done
@@ -249,7 +248,7 @@ download_and_launch() {
 		update_screenshot
 		TOR_RUNNING=$(gocr $WORKSPACE/screenshot.png 2>/dev/null | egrep "(Search securely|Tor Is NOT all you need to browse|There are many ways you can help)" || true)
 		if [ -n "$TOR_RUNNING" ] ; then
-			echo "$(date -u) - torbrowser is working is it should, good."
+			echo "$(date -u) - torbrowser is working as it should, good."
 			break
 		fi
 	done

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list